==> spektralwerk_scpi_client-0.2.1.tar.gz: spektralwerk_scpi_client-0.2.1/spektralwerk_scpi_client/scpi/commands.py <==
import enum


class SCPICommand(enum.StrEnum):
    # SCPI standard/IEEE 488 commands
    IDN_QUERY = "*IDN?"
    ESR_QUERY = "*ESR?"
    SYSTEM_ERROR_NEXT_QUERY = "SYSTem:ERRor:NEXT?"

    # Spektralwerk SCPI commands
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_COMMAND = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage"
    )
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_QUERY = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage?"
    )
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_MAX_QUERY = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage:MAXimum?"
    )
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_MIN_QUERY = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage:MINimum?"
    )
    DEVICE_SPECTROMETER_PEAK_QUERY = "DEVice:SPECtrometer:PEAK?"
    DEVICE_SPECTROMETER_PIXELS_COUNT_QUERY = "DEVice:SPECtrometer:PIXels:COUNt?"
    DEVICE_SPECTROMETER_PIXELS_WAVELENGTH_QUERY = (
        "DEVice:SPECtrometer:PIXels:WAVelength?"
    )
    DEVICE_SPECTROMETER_RESOLUTION_QUERY = "DEVice:SPECtrometer:RESolution?"
    MEASURE_SPECTRUM_AVERAGE_NUMBER_COMMAND = "MEASure:SPECtrum:AVERage:NUMBer"
    MEASURE_SPECTRUM_AVERAGE_NUMBER_QUERY = "MEASure:SPECtrum:AVERage:NUMBer?"
    MEASURE_SPECTRUM_AVERAGE_NUMBER_MAX_QUERY = (
        "MEASure:SPECtrum:AVERage:NUMBer:MAXimum?"
    )
    MEASURE_SPECTRUM_AVERAGE_NUMBER_MIN_QUERY = (
        "MEASure:SPECtrum:AVERage:NUMBer:MINimum?"
    )
    MEASURE_SPECTRUM_EXPOSURE_TIME_COMMAND = "MEASure:SPECtrum:EXPosure:TIME"
    MEASURE_SPECTRUM_EXPOSURE_TIME_QUERY = "MEASure:SPECtrum:EXPosure:TIME?"
    MEASURE_SPECTRUM_EXPOSURE_TIME_MAX_QUERY = "MEASure:SPECtrum:EXPosure:TIME:MAXimum?"
    MEASURE_SPECTRUM_EXPOSURE_TIME_MIN_QUERY = "MEASure:SPECtrum:EXPosure:TIME:MINimum?"
    MEASURE_SPECTRUM_SAMPLE_RAW_QUERY = "MEASure:SPECtrum:SAMPle:RAW?"
    MEASURE_SPECTRUM_SAMPLE_RAW_AVERAGED_QUERY = "MEASure:SPECtrum:SAMPle:RAW:AVERaged?"

==> spektralwerk_scpi_client-0.2.2.tar.gz: spektralwerk_scpi_client-0.2.2/spektralwerk_scpi_client/scpi/commands.py <==
import enum


class SCPICommand(enum.StrEnum):
    # SCPI standard/IEEE 488 commands
    IDN_QUERY = "*IDN?"
    ESR_QUERY = "*ESR?"
    SYSTEM_ERROR_NEXT_QUERY = "SYSTem:ERRor:NEXT?"

    # Spektralwerk SCPI commands
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_COMMAND = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage"
    )
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_QUERY = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage?"
    )
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_MAX_QUERY = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage:MAXimum?"
    )
    DEVICE_SPECTROMETER_BACKGROUND_OFFSET_VOLTAGE_MIN_QUERY = (
        "DEVice:SPECtrometer:BACKground:OFFSet:VOLTage:MINimum?"
    )
    DEVICE_SPECTROMETER_PEAK_QUERY = "DEVice:SPECtrometer:PEAK?"
    DEVICE_SPECTROMETER_PIXELS_COUNT_QUERY = "DEVice:SPECtrometer:PIXels:COUNt?"
    DEVICE_SPECTROMETER_PIXELS_WAVELENGTH_QUERY = (
        "DEVice:SPECtrometer:PIXels:WAVelengths?"
    )
    DEVICE_SPECTROMETER_RESOLUTION_QUERY = "DEVice:SPECtrometer:RESolution?"
    MEASURE_SPECTRUM_AVERAGE_NUMBER_COMMAND = "MEASure:SPECtrum:AVERage:NUMBer"
    MEASURE_SPECTRUM_AVERAGE_NUMBER_QUERY = "MEASure:SPECtrum:AVERage:NUMBer?"
    MEASURE_SPECTRUM_AVERAGE_NUMBER_MAX_QUERY = (
        "MEASure:SPECtrum:AVERage:NUMBer:MAXimum?"
    )
    MEASURE_SPECTRUM_AVERAGE_NUMBER_MIN_QUERY = (
        "MEASure:SPECtrum:AVERage:NUMBer:MINimum?"
    )
    MEASURE_SPECTRUM_EXPOSURE_TIME_COMMAND = "MEASure:SPECtrum:EXPosure:TIME"
    MEASURE_SPECTRUM_EXPOSURE_TIME_QUERY = "MEASure:SPECtrum:EXPosure:TIME?"
    MEASURE_SPECTRUM_EXPOSURE_TIME_MAX_QUERY = "MEASure:SPECtrum:EXPosure:TIME:MAXimum?"
    MEASURE_SPECTRUM_EXPOSURE_TIME_MIN_QUERY = "MEASure:SPECtrum:EXPosure:TIME:MINimum?"
    MEASURE_SPECTRUM_SAMPLE_RAW_QUERY = "MEASure:SPECtrum:SAMPle:RAW?"
    MEASURE_SPECTRUM_SAMPLE_RAW_AVERAGED_QUERY = "MEASure:SPECtrum:SAMPle:RAW:AVERaged?"
